Disable use of R4 as a promotable register

When we are using implicit suspend checks we can potentially
use r4 as a register into which variables can be promoted.  However
the runtime doesn't save this and thus will corrupt it.  Not good.

This disables the promotion of r4 until we can figure out how
to make the runtime save it properly.

Change-Id: Ib95ce93579e1c364de5ecc8e728f2cb7990da77a
diff --git a/runtime/arch/arm/fault_handler_arm.cc b/runtime/arch/arm/fault_handler_arm.cc
index aaba598..3bbec71 100644
--- a/runtime/arch/arm/fault_handler_arm.cc
+++ b/runtime/arch/arm/fault_handler_arm.cc
@@ -35,7 +35,7 @@
 
 extern "C" void art_quick_throw_null_pointer_exception();
 extern "C" void art_quick_throw_stack_overflow(void*);
-extern "C" void art_quick_test_suspend();
+extern "C" void art_quick_implicit_suspend();
 
 // Get the size of a thumb2 instruction in bytes.
 static uint32_t GetInstructionSize(uint8_t* pc) {
@@ -142,7 +142,7 @@
   if (found) {
     LOG(DEBUG) << "suspend check match";
     // This is a suspend check.  Arrange for the signal handler to return to
     // art_quick_test_suspend.  Also set LR so that after the suspend check it
     // will resume the instruction (current PC + 2).  PC points to the
     // ldr r0,[r0,#0] instruction (r0 will be 0, set by the trigger).
 
@@ -151,7 +151,7 @@
     LOG(DEBUG) << "arm lr: " << std::hex << sc->arm_lr;
     LOG(DEBUG) << "arm pc: " << std::hex << sc->arm_pc;
     sc->arm_lr = sc->arm_pc + 3;      // +2 + 1 (for thumb)
-    sc->arm_pc = reinterpret_cast<uintptr_t>(art_quick_test_suspend);
+    sc->arm_pc = reinterpret_cast<uintptr_t>(art_quick_implicit_suspend);
 
     // Now remove the suspend trigger that caused this fault.
     Thread::Current()->RemoveSuspendTrigger();
@@ -142,7 +142,7 @@
     LOG(DEBUG) << "suspend check match";
     // This is a suspend check.  Arrange for the signal handler to return to
-    // art_quick_test_suspend.  Also set LR so that after the suspend check it
+    // art_quick_implicit_suspend.  Also set LR so that after the suspend check it
     // will resume the instruction (current PC + 2).  PC points to the
     // ldr r0,[r0,#0] instruction (r0 will be 0, set by the trigger).